import serial
import matplotlib.pyplot as plt
import matplotlib.animation as animation
import numpy as np


class Data:
    def __init__(self, name):
        pass

    def get_frame(self):
        pass


class MockData(Data):
    X = 8
    Y = 8

    def __init__(self, name):
        self.t = 0

    def get_frame(self):
        self.t += 1
        if self.t >= self.X:
            self.t = 0

        frame = np.empty([self.X, self.Y])
        for x in range(self.X):
            v = x-self.t
            v %= self.X
            for y in range(self.Y):
                frame[x, y] = v
        return frame


class SerialData(Data):
    BAUD = 2000000
    X = 8
    Y = 8

    def __init__(self, name):
        self.name = name
        self.com = serial.Serial(name, self.BAUD)
        self.com.flushInput()

    def get_frame(self):
        is_ok = True
        if self.com.inWaiting() == 0:
            return None
        d = self.com.read()
        while d != b'[':
            d = self.com.read()
        self.com.readline()
        frame = np.empty([self.X, self.Y])
        for i in range(self.Y):
            line = self.com.readline()
            line = line.decode("utf-8")
            line = line[:-3]
            line = line.split('\t')
            for j in range(self.Y):
                try:
                    frame[i, j] = float(line[j])/4
                except ValueError:
                    is_ok = False
        self.com.flushInput()
        if is_ok:
            return frame
        return None

    def close(self):
        self.com.close()
